from mangum                                              import Mangum
from osbot_utils.utils.Env                               import get_env
from mgraph_ai_serverless.fast_api.MGraph_AI_Serverless__Fast_API import MGraph_AI_Serverless__Fast_API

fast_api__mgraph_ai_serverless = MGraph_AI_Serverless__Fast_API().setup()
app                  = fast_api__mgraph_ai_serverless.app()
run                  = Mangum(app)

if __name__ == "__main__":                              # pragma: no cover
    import uvicorn
    port = get_env('PORT', 8080)
    uvicorn.run(app, host="0.0.0.0", port=port)


from osbot_fast_api.api.Fast_API                                             import Fast_API

class Graphviz_MGraph_AI___Fast_API(Fast_API):
    base_path  : str  = '/'
    enable_cors: bool = True

    # def setup_routes(self):
    #     self.add_routes(Routes__Info      )
    #     self.add_routes(Routes__Web_Root  )
    #     self.add_routes(Routes__Graphviz  )
    #     self.add_routes(Routes__Matplotlib)
    #     self.add_routes(Routes__Browser   )
    #     self.add_routes(Routes__Debug     )


